@@ -13,6 +13,7 @@ from typing import Any, Dict, List, Optional, Type
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import padding
 from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
+from zeroconf.asyncio import AsyncZeroconf
 
 from .exceptions import ProtocolError
 from .response import (
@@ -35,11 +36,18 @@ class Client(ABC):
     _sock: Optional[socket.socket] = None
     _ts_diff: Optional[float] = None
 
-    def __init__(self, host: str, token: Optional[str], port: int = 9009) -> None:
+    def __init__(
+        self,
+        host: str,
+        token: Optional[str],
+        port: int = 9009,
+        zeroconf: AsyncZeroconf = None,
+    ) -> None:
         """Initialize the client."""
         self._host = host
         self._token = bytes.fromhex(token) if token else None
         self._port = port
+        self._zeroconf = zeroconf
         self._id = SystemRandom().randrange(0x1000000)
 
     def __enter__(self) -> "Client":
@@ -60,12 +68,24 @@ class Client(ABC):
     def _create_socket(cls) -> socket.socket:
         pass
 
+    async def _resolve(self, host: str) -> str:
+        if self._zeroconf is not None and host.endswith(".local"):
+            info = await self._zeroconf.async_get_service_info(
+                "_rabbitair._udp.local.", host + "."
+            )
+            if info:
+                addr = info.parsed_addresses()
+                if len(addr) > 0:
+                    return addr[0]
+        return host
+
     async def _start(self) -> None:
         assert self._sock is None
         self._sock = self._create_socket()
         self._sock.setblocking(False)
         loop = asyncio.get_running_loop()
-        await loop.sock_connect(self._sock, (self._host, self._port))
+        host = await self._resolve(self._host)
+        await loop.sock_connect(self._sock, (host, self._port))
 
     def _stop(self) -> None:
         assert self._sock is not None
